# Sync Tracks From Spotify Playlists

In this guide you will learn how to limit the tracks you sync to your USB by providing a Spotify playlist with only the desired tracks in it.

## Prerequisites

* [Setup object storage for syncing files](setup_object_storage.md)
* [Configure the `sync` options](../tutorials/getting_started/configuration.md#sync-config)
* Have a playlist generated by [Create Spotify Playlists From Other Users' Uploads](spotify_playlist_from_upload.md)

## Why sync tracks from a Spotify playlist?
You're probably using DJ Tools to manage a shared track collection with friends who have a similar taste in music. Despite this, we all have our own style and don't necessarily want to indiscriminately sync every track that every other user syncs to the Beatcloud.

The purpose of this feature is to allow you to limit the tracks you sync to your `usb_path` by providing a Spotify playlists with only the desired tracks in it. It's intended that this playlist was created using the sister feature [create Spotify playlist from other users' uploads](spotify_playlist_from_upload.md), though there's nothing strictly preventing you from using any playlist that's registered in `spotify_playlists.yaml`.

## How it's done

1. Run the command `djtools --download-spotify-playlist <playlist name>`
    - Note that `<playlist name>` must be a registered Spotify playlist in `spotify_playlists.yaml`
    - If `<playlist name>` is the playlist generated by the [create Spotify playlist from other users' uploads](spotify_playlist_from_upload.md) feature, as is intended, then `<playlist name>` will automatically have been inserted into `spotify_playlists.yaml`
